@@ -5,7 +5,7 @@ from eoe import utils
 
 passperso = Blueprint('passperso', __name__, url_prefix = '/passperso')
 
-@passperso.route('')
+@passperso.route('/')
 @login_required
 def show():
 
